<?php

declare(strict_types=1);

namespace Drupal\contact_automatic_subject\Entity;

use Drupal\contact\Entity\Message as CoreMessage;

/**
 * Extends to the core contact message entity to generate a default subject.
 */
class Message extends CoreMessage {

  /**
   * {@inheritdoc}
   *
   * @see \Drupal\contact\MessageForm::save()
   *   Calls $message->save() which it notes is a no-op in core but intended
   *   for contrib to implement things like message storage, etc. This is done
   *   right before sending the email via the mail handler.
   */
  public function save() {

    if ($this->getSubject() !== null) {
      return SAVED_NEW;
    }

    // If the sender name is empty, only use the email address for the generated
    // subject.
    if (empty($this->getSenderName())) {

      $this->setSubject(\t(
        'Message from @senderMail',
        ['@senderMail' => $this->getSenderMail()],
      ));

      return SAVED_NEW;

    }

    // Use both when the sender name and email are available.
    $this->setSubject(\t('Message from @senderName (@senderMail)', [
      '@senderMail' => $this->getSenderMail(),
      '@senderName' => $this->getSenderName(),
    ]));

    return SAVED_NEW;

  }

}
